==> banking-branch_14.8.0.0.0-Plus1.zip: banking-branch_14.8.0.0.0-Plus1_20250419/content/banking-branch/14.8.0.0.0/dsugu/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-E3486808-D80C-4A91-A60D-330B74476BDB"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Overview of Deposit Services",
                    "href":"overview-deposit-services.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Prerequisite",
                            "href":"prerequisite.html"
                        },
                        {
                            "title":"<span class=\"secnum\">1.2 </span> About Main Menu",
                            "href":"main-menu.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Customer Information",
                    "href":"customer-information-section-1.html"
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Deposit View",
                    "href":"deposit-view.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">3.1 </span> Deposit 360",
                            "href":"deposit-360.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> TD Transactions",
                    "href":"td-transactions.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">4.1 </span> Term Deposit Account Opening",
                            "href":"td-account-opening.html"
                        },
                        {
                            "title":"<span class=\"secnum\">4.2 </span> Top Up",
                            "href":"td-top.html"
                        },
                        {
                            "title":"<span class=\"secnum\">4.3 </span> Rollover",
                            "href":"td-rollover.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">4.3.1 </span> Simulation Details",
                                    "href":"td-rollover-simulation-details.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">4.3.2 </span> Settlement Details",
                                    "href":"td-rollover-settlement-details.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">4.4 </span> Redemption",
                            "href":"td-redemption.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">5 </span> TD Maintenances",
                    "href":"td-maintenances.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">5.1 </span> Term Deposit Amount Block",
                            "href":"td-create-amount-block.html"
                        },
                        {
                            "title":"<span class=\"secnum\">5.2 </span> View and Modify Amount Block",
                            "href":"td-view-and-modify-amount-block.html"
                        },
                        {
                            "title":"<span class=\"secnum\">5.3 </span> Term Deposit Payout Modification",
                            "href":"td-payout-modification.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">5.3.1 </span> View TD Payout Modification",
                                    "href":"td-payout-modification-view.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">5.3.2 </span> Modify TD Payout Modification",
                                    "href":"td-payout-modification-modify.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">5.4 </span> Term Deposit Account Modification",
                            "href":"td-account-modification.html"
                        },
                        {
                            "title":"<span class=\"secnum\">5.5 </span> Term Deposit Joint Holder Maintenance",
                            "href":"td-joint-holder-maintenance.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">5.5.1 </span> Maintain Joint Holder Details",
                                    "href":"td-joint-holder-maintenance_maintain-joint-holder-details.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">5.6 </span> Term Deposit Nominee Details Update",
                            "href":"td-nominee-details-update.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">5.6.1 </span> Add Nominee",
                                    "href":"td-nominee-details-update_add-nominee.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">5.6.2 </span> View Nominee Details",
                                    "href":"td-nominee-details-update_view-nominee.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">5.6.3 </span> Edit Nominee Details",
                                    "href":"td-nominee-details-update_edit-nominee.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">6 </span> TD Inquiries",
                    "href":"td-inquiries.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">6.1 </span> Account Transactions",
                            "href":"td-account-transactions.html"
                        },
                        {
                            "title":"<span class=\"secnum\">6.2 </span> Certificate",
                            "href":"td-certificate.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">7 </span> Recurring Deposit View",
                    "href":"rd-view.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">7.1 </span> Recurring Deposit 360",
                            "href":"recurring-deposit-360.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">8 </span> RD Transactions",
                    "href":"rd-transactions.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">8.1 </span> Account Opening",
                            "href":"rd-account-opening.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">8.1.1 </span> Simulation",
                                    "href":"rd-account-opening_rd-simulation.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">8.1.2 </span> Payin Details",
                                    "href":"rd-account-opening_rd-payin-details.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">8.1.3 </span> Payout Details",
                                    "href":"rd-account-opening_rd-payout-details.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">8.1.4 </span> Additional Details",
                                    "href":"rd-account-opening_rd-additional-details.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">8.2 </span> Recurring Deposit Payment",
                            "href":"rd-payment.html"
                        },
                        {
                            "title":"<span class=\"secnum\">8.3 </span> Redemption",
                            "href":"rd-redemption.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">9 </span> RD Maintenances",
                    "href":"rd-maintenances.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">9.1 </span> Recurring Deposit Amount Block",
                            "href":"rd-amount-block.html"
                        },
                        {
                            "title":"<span class=\"secnum\">9.2 </span> View and Modify Amount Block",
                            "href":"rd-view-and-modify-amount-block.html"
                        },
                        {
                            "title":"<span class=\"secnum\">9.3 </span> Recurring Deposit Payout Modification",
                            "href":"rd-payout-modification.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">9.3.1 </span> Recurring Deposit Payout Modification - Auto-pay Instruction",
                                    "href":"rd-payout-modification-auto-pay.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">9.3.2 </span> Recurring Deposit Payout Modification - Payout Instruction",
                                    "href":"rd-payout-modification-payout.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">9.4 </span> Recurring Deposit Account Modification",
                            "href":"rd-account-modification.html"
                        },
                        {
                            "title":"<span class=\"secnum\">9.5 </span> Recurring Deposit Joint Holder Maintenance",
                            "href":"rd-joint-holder-maintenance.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">9.5.1 </span> Maintain Joint Holder Details",
                                    "href":"rd-joint-holder-maintenance_maintain-joint-holder-details.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">9.6 </span> Recurring Deposit Nominee Details Update",
                            "href":"rd-nominee-details-update.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">9.6.1 </span> Add Nominee",
                                    "href":"rd-nominee-details-update_add-nominee.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">9.6.2 </span> View Nominee Details",
                                    "href":"rd-nominee-details-update_view-nominee.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">9.6.3 </span> Edit Nominee Details",
                                    "href":"rd-nominee-details-update_edit-nominee.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">10 </span> RD Inquiries",
                    "href":"rd-inquiries.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">10.1 </span> Recurring Deposit Account Transactions",
                            "href":"recurring-deposit-account-transactions.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">11 </span> Access Restriction",
                    "href":"access-restriction-1.html"
                },
                {
                    "title":"<span class=\"secnum\">A </span> Functional Activity Codes",
                    "href":"functional-activity-codes.html"
                },
                {
                    "title":"Index",
                    "href":"book-index.html"
                }
            ]
        }
    ]
});

==> banking-branch_14.8.1.0.0-Plus1.zip: banking-branch_14.8.1.0.0-Plus1_20251105/content/banking-branch/14.8.1.0.0/dsugu/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-E3486808-D80C-4A91-A60D-330B74476BDB"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Overview of Deposit Services",
                    "href":"overview-deposit-services.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Prerequisite",
                            "href":"prerequisite.html"
                        },
                        {
                            "title":"<span class=\"secnum\">1.2 </span> About Main Menu",
                            "href":"main-menu.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Customer Information",
                    "href":"customer-information-section-1.html"
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Deposit View",
                    "href":"deposit-view.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">3.1 </span> Deposit 360",
                            "href":"deposit-360.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> TD Transactions",
                    "href":"td-transactions.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">4.1 </span> Term Deposit Account Opening",
                            "href":"td-account-opening.html"
                        },
                        {
                            "title":"<span class=\"secnum\">4.2 </span> Top Up",
                            "href":"td-top.html"
                        },
                        {
                            "title":"<span class=\"secnum\">4.3 </span> Rollover",
                            "href":"td-rollover.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">4.3.1 </span> Simulation Details",
                                    "href":"td-rollover---simulation-details.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">4.3.2 </span> Settlement Details",
                                    "href":"td-rollover---settlement-details.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">4.4 </span> Redemption",
                            "href":"td-redemption.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">5 </span> TD Maintenances",
                    "href":"td-maintenances.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">5.1 </span> Term Deposit Amount Block",
                            "href":"td-create-amount-block.html"
                        },
                        {
                            "title":"<span class=\"secnum\">5.2 </span> View and Modify Amount Block",
                            "href":"td-view-modify-amount-block.html"
                        },
                        {
                            "title":"<span class=\"secnum\">5.3 </span> Term Deposit Payout Modification",
                            "href":"td-payout-modification.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">5.3.1 </span> View TD Payout Modification",
                                    "href":"td-payout-modification---view.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">5.3.2 </span> Modify TD Payout Modification",
                                    "href":"td-payout-modification---modify.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">5.4 </span> Term Deposit Account Modification",
                            "href":"td-account-modification.html"
                        },
                        {
                            "title":"<span class=\"secnum\">5.5 </span> Term Deposit Joint Holder Maintenance",
                            "href":"td-joint-holder-maintenance.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">5.5.1 </span> Maintain Joint Holder Details",
                                    "href":"td-joint-holder-maintenance-maintain-joint-holder-details.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">5.6 </span> Term Deposit Nominee Details Update",
                            "href":"td-nominee-details-update.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">5.6.1 </span> Add Nominee",
                                    "href":"td-nominee-details-update-add-nominee.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">5.6.2 </span> View Nominee Details",
                                    "href":"td-nominee-details-update-view-nominee.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">5.6.3 </span> Edit Nominee Details",
                                    "href":"td-nominee-details-update-edit-nominee.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">6 </span> TD Inquiries",
                    "href":"td-inquiries.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">6.1 </span> Account Transactions",
                            "href":"td-account-transactions.html"
                        },
                        {
                            "title":"<span class=\"secnum\">6.2 </span> Certificate",
                            "href":"td-certificate.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">7 </span> Recurring Deposit View",
                    "href":"rd-view.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">7.1 </span> Recurring Deposit 360",
                            "href":"recurring-deposit-360.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">8 </span> RD Transactions",
                    "href":"rd-transactions.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">8.1 </span> Account Opening",
                            "href":"rd-account-opening.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">8.1.1 </span> Simulation",
                                    "href":"rd-account-opening-rd-simulation.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">8.1.2 </span> Payin Details",
                                    "href":"rd-account-opening-rd-payin-details.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">8.1.3 </span> Payout Details",
                                    "href":"rd-account-opening-rd-payout-details.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">8.1.4 </span> Additional Details",
                                    "href":"rd-account-opening-rd-additional-details.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">8.2 </span> Recurring Deposit Payment",
                            "href":"rd-payment.html"
                        },
                        {
                            "title":"<span class=\"secnum\">8.3 </span> Redemption",
                            "href":"rd-redemption.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">9 </span> RD Maintenances",
                    "href":"rd-maintenances.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">9.1 </span> Recurring Deposit Amount Block",
                            "href":"rd-amount-block.html"
                        },
                        {
                            "title":"<span class=\"secnum\">9.2 </span> View and Modify Amount Block",
                            "href":"rd-view-modify-amount-block.html"
                        },
                        {
                            "title":"<span class=\"secnum\">9.3 </span> Recurring Deposit Payout Modification",
                            "href":"rd-payout-modification.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">9.3.1 </span> Recurring Deposit Payout Modification - Auto-pay Instruction",
                                    "href":"rd-payout-modification---auto-pay.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">9.3.2 </span> Recurring Deposit Payout Modification - Payout Instruction",
                                    "href":"rd-payout-modification---payout.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">9.4 </span> Recurring Deposit Account Modification",
                            "href":"rd-account-modification.html"
                        },
                        {
                            "title":"<span class=\"secnum\">9.5 </span> Recurring Deposit Joint Holder Maintenance",
                            "href":"rd-joint-holder-maintenance.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">9.5.1 </span> Maintain Joint Holder Details",
                                    "href":"rd-joint-holder-maintenance-maintain-joint-holder-details.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">9.6 </span> Recurring Deposit Nominee Details Update",
                            "href":"rd-nominee-details-update.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">9.6.1 </span> Add Nominee",
                                    "href":"rd-nominee-details-update-add-nominee.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">9.6.2 </span> View Nominee Details",
                                    "href":"rd-nominee-details-update-view-nominee.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">9.6.3 </span> Edit Nominee Details",
                                    "href":"rd-nominee-details-update-edit-nominee.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">10 </span> RD Inquiries",
                    "href":"rd-inquiries.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">10.1 </span> Recurring Deposit Account Transactions",
                            "href":"recurring-deposit-account-transactions.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">11 </span> Access Restriction",
                    "href":"access-restriction-1.html"
                },
                {
                    "title":"<span class=\"secnum\">A </span> Functional Activity Codes",
                    "href":"functional-activity-codes.html"
                },
                {
                    "title":"Index",
                    "href":"book-index.html"
                }
            ]
        }
    ]
});
